@@ -24,7 +24,7 @@ class RunSnpDetection(object):
         self.logger = logging.getLogger(__name__)
         self.logger.setLevel(logging.INFO)
         # create file handler which logs even debug messages
-        fh = logging.FileHandler('bohra.log')
+        fh = logging.FileHandler('bohra.setup.log')
         fh.setLevel(logging.INFO)
         # create console handler with a higher log level
         ch = logging.StreamHandler()
@@ -73,6 +73,7 @@ class RunSnpDetection(object):
         self.keep = True if args.keep == 'Y' else False
         self.check_rerun()
         self.gubbins = args.gubbins 
+        self.verbose = '--verbose' if args.verbose else ''
         # other variables
         # min aln 
         self.minaln = args.minaln
@@ -88,7 +89,7 @@ class RunSnpDetection(object):
         
         self.user = getpass.getuser()
         
-        self.gubbins = False
+        # self.gubbins = False
         self.use_singularity = False
         self.mdu = args.mdu
         # self.logger.info(f"{self.mdu}")
@@ -106,6 +107,7 @@ class RunSnpDetection(object):
         self.cpus = args.cpus
         # kraken db settings
         self.kraken_db = args.kraken_db
+        self.kraken_threads = args.kraken_threads
         self.run_kraken = False
         self.assembler = args.assembler
         self.snippy_version = ''
@@ -274,6 +276,8 @@ class RunSnpDetection(object):
         '''
         ensure that kraken2 DB is not empty
         '''
+        self.logger.info(f'Checking that {k2db} is a directory, checking that files are not empty')
+        print(pathlib.Path(k2db))
         if pathlib.Path(k2db).is_dir():
                 self.logger.info(f'Found {k2db}, checking that files are not empty')
                 kmerfiles = sorted(pathlib.Path(k2db).glob('*'))
@@ -282,6 +286,10 @@ class RunSnpDetection(object):
                     s.append(self.check_size_file(pathlib.Path(k2db) / kmerfiles[k]))
                 if 0 not in s:
                     self.run_kraken = True
+                    return True
+        else:
+            self.logger.info(f'{k2db} is not a directory.')
+            return False
         
 
     def check_kraken2DB(self):
@@ -289,23 +297,29 @@ class RunSnpDetection(object):
         ensure that DB is present and not emtpy
         '''
         self.logger.info(f'Searching for kraken2 DB {self.kraken_db}')
-        if self.kraken_db != f"{pathlib.Path(os.environ['KRAKEN2_DEFAULT_DB'])}":
+        if self.kraken_db == 'KRAKEN2_DEFAULT_DB':
+            try: # check that there is an environment value set for kraken2 db
+                k2db = pathlib.Path(os.environ["KRAKEN2_DEFAULT_DB"])
+                self.logger.info(f"You are using the deafult kraken2 database at : {os.environ['KRAKEN2_DEFAULT_DB']}")
+                if self.check_kraken2_files(k2db = k2db):
+                    self.kraken_db = f"{k2db}"
+                    # self.logger.info(f"You are using the deafult kraken2 database at : {os.environ['KRAKEN2_DEFAULT_DB']}")
+
+            except KeyError:
+                self.run_kraken = False # don't run kraken
+        
+        else:
             self.logger.info('You are attempting to use a custom kraken2 DB. This is pretty advanced, good luck!')
             if pathlib.Path(self.kraken_db).exists():
                 self.logger.info(f"{self.kraken_db} has been found.")
                 self.check_kraken2_files(k2db = self.kraken_db)
             else:
-                self.logger.warning(f"It seems that your settings for the kraken DB are incorrect. Bohra will check for the presence of a default kraken2 DB.")
-        elif "KRAKEN2_DEFAULT_DB" in os.environ:
-            k2db = pathlib.Path(os.environ["KRAKEN2_DEFAULT_DB"])
-            if self.check_kraken2_files(k2db = self.kraken_db):
-                self.kraken_db = f"{k2db}"
+                self.logger.warning(f"It seems that your settings for the kraken DB are incorrect.")           
         
         if self.run_kraken:
             self.logger.info(f"Congratulations your kraken database is present")  
         else:
-            self.logger.warning(f"Your kraken DB is not installed in the expected path. Please re-read bohra installation instructions.")
-            raise SystemExit
+            self.logger.warning(f"kraken DB is not installed in the expected path. Speciation will not be performed.")
 
         
     def run_with_gubbins(self):
@@ -487,12 +501,13 @@ class RunSnpDetection(object):
             returns True (or fails with FileNotFoundError)
         '''
         
-        if not path.exists():
-            self.logger.warning(f"The {path.name} does not exist.")
-            raise FileNotFoundError(f"{path.name}")
-        else:
+        if path.exists() and os.access(path, os.R_OK):
             if v == True:
                 self.logger.info(f"Found {path.name}.")
+            
+        else:
+            self.logger.warning(f"The {path.name} does not exist or is not accessible.")
+            raise FileNotFoundError(f"{path.name}")
 
             return True
     
@@ -527,7 +542,7 @@ class RunSnpDetection(object):
         if f"{read_source}"[0] != '/':
             read_source = self.workdir / read_source
         
-        if read_source.exists():
+        if read_source.exists() and os.access(read_source, os.R_OK):
             I = R / f"{isolate_id}" # the directory where reads will be stored for the isolate
             if not I.exists():
                 I.mkdir()
@@ -864,7 +879,9 @@ class RunSnpDetection(object):
             'gubbins': self.gubbins,
             'pipeline': self.pipeline,
             'min_cov': self.mincov,
+            'run_kraken': 'speciation' if self.run_kraken else 'no_speciation',
             'kraken_db': f"{self.kraken_db}",
+            'kraken_threads': self.kraken_threads,
             'preview': self.preview, 
             'prefill_path': self.prefillpath if self.prefillpath != '' else 'nopath',
             'snippy_singularity': self.snippy_singularity,
@@ -905,7 +922,7 @@ class RunSnpDetection(object):
         if self.cluster:
             cmd = f"{self.cluster_cmd()} -s {snake_name} -d {wd} {force} {singularity_string} --latency-wait 1200"
         else:
-            cmd = f"snakemake {dry} -s {snake_name} {singularity_string} -j {self.cpus} -d {self.job_id} {force} --verbose 2>&1"
+            cmd = f"snakemake {dry} -s {snake_name} {singularity_string} -j {self.cpus} -d {self.job_id} {force} {self.verbose} 2>&1 | tee -a bohra.log"
             # cmd = f"snakemake -s {snake_name} --cores {self.cpus} {force} "
         self.logger.info(f"Running job : {self.job_id} with {cmd} this may take some time. We appreciate your patience.")
         wkf = subprocess.run(cmd, shell = True)
