@@ -1,4 +1,4 @@
-import toml, pathlib, subprocess, sys
+import toml, pathlib, subprocess, sys, os
 
 from snakemake import shell
 
@@ -17,7 +17,7 @@ def generate_asm_cmd(assembler, r1, r2, isolate, threads = 4, memory = 8):
 def generate_cmd(prefill, r1, r2, isolate, assembler, data):
     
     prfl = pathlib.Path(prefill, isolate, 'contigs.fa')
-    if prfl.exists():
+    if prfl.exists() and os.access(f"{prfl}", os.R_OK):
         cmd = f"cp {prfl} {isolate}/contigs.fa"
         data[isolate]['assembly']['source'] = f"Prefilled from: {prfl}"
         print(f'Isolate has passed quality checks and assembly will be retrieved from {prfl}.')
